@@ -769,7 +769,7 @@ class PublishedDataset:
         '''
         if self._is_public is None:
             self._fill_missing_fields()
-        return self.is_public
+        return self._is_public
 
     @classmethod
     def decode(cls, d, api):
